EXPORTS
	??1CFCPlugInEngine@@UAE@XZ @ 1 NONAME ; CFCPlugInEngine::~CFCPlugInEngine(void)
	?CreateNewSessionL@CFCPlugInEngine@@QAEAAVCFCSession@@ABVTDesC8@@KK@Z @ 2 NONAME ; class CFCSession & CFCPlugInEngine::CreateNewSessionL(class TDesC8 const &, unsigned long, unsigned long)
	?FormatAttributeFieldsL@CFCPlugInEngine@@QAEAAV?$RPointerArray@VCSdpFmtAttributeField@@@@ABVCFCSession@@@Z @ 3 NONAME ; class RPointerArray<class CSdpFmtAttributeField> & CFCPlugInEngine::FormatAttributeFieldsL(class CFCSession const &)
	?IsReceiverL@CFCPlugInEngine@@QAEHABVCFCSession@@@Z @ 4 NONAME ; int CFCPlugInEngine::IsReceiverL(class CFCSession const &)
	?NewL@CFCPlugInEngine@@SAPAV1@AAVMFCObserver@@@Z @ 5 NONAME ; class CFCPlugInEngine * CFCPlugInEngine::NewL(class MFCObserver &)
	?NewLC@CFCPlugInEngine@@SAPAV1@AAVMFCObserver@@@Z @ 6 NONAME ; class CFCPlugInEngine * CFCPlugInEngine::NewLC(class MFCObserver &)
	?PeekDocumentL@CFCPlugInEngine@@QAEXABVCFCSession@@ABVCSdpDocument@@@Z @ 7 NONAME ; void CFCPlugInEngine::PeekDocumentL(class CFCSession const &, class CSdpDocument const &)
	?PlugInByNameL@CFCPlugInEngine@@QAEPAVMFCPlugIn@@ABVTDesC8@@@Z @ 8 NONAME ; class MFCPlugIn * CFCPlugInEngine::PlugInByNameL(class TDesC8 const &)
	?ReleaseSession@CFCPlugInEngine@@QAEXABVCFCSession@@@Z @ 9 NONAME ; void CFCPlugInEngine::ReleaseSession(class CFCSession const &)
	?SendToNetL@CFCPlugInEngine@@QAEXABVCFCSession@@PAVHBufC8@@@Z @ 10 NONAME ; void CFCPlugInEngine::SendToNetL(class CFCSession const &, class HBufC8 *)
	?SetFormatAttributeFieldsL@CFCPlugInEngine@@QAEXABVCFCSession@@PAV?$RPointerArray@VCSdpFmtAttributeField@@@@@Z @ 11 NONAME ; void CFCPlugInEngine::SetFormatAttributeFieldsL(class CFCSession const &, class RPointerArray<class CSdpFmtAttributeField> *)
	?SetSessionPortL@CFCPlugInEngine@@QAEXAAVCFCSession@@K@Z @ 12 NONAME ; void CFCPlugInEngine::SetSessionPortL(class CFCSession &, unsigned long)
	?StartConnectionL@CFCPlugInEngine@@QAEXABVCFCSession@@@Z @ 13 NONAME ; void CFCPlugInEngine::StartConnectionL(class CFCSession const &)
	?SupportedProtocolL@CFCPlugInEngine@@QAEPAVCDesC8Array@@XZ @ 14 NONAME ; class CDesC8Array * CFCPlugInEngine::SupportedProtocolL(void)
	?UpdateAnswerL@CFCPlugInEngine@@QAEXABVCFCSession@@AAVCSdpDocument@@@Z @ 15 NONAME ; void CFCPlugInEngine::UpdateAnswerL(class CFCSession const &, class CSdpDocument &)
	?UpdateNeededL@CFCPlugInEngine@@QAEHABVCFCSession@@@Z @ 16 NONAME ; int CFCPlugInEngine::UpdateNeededL(class CFCSession const &)
	?UpdateOfferL@CFCPlugInEngine@@QAEXABVCFCSession@@AAVCSdpDocument@@@Z @ 17 NONAME ; void CFCPlugInEngine::UpdateOfferL(class CFCSession const &, class CSdpDocument &)
	?UpdateSessionL@CFCPlugInEngine@@QAEXAAVCFCSession@@K@Z @ 18 NONAME ; void CFCPlugInEngine::UpdateSessionL(class CFCSession &, unsigned long)

